@@ -8,14 +8,11 @@ from sys import argv
 from os import getcwd
 from PyQt5 import uic, QtWidgets, QtGui
 from tkcolorpicker import askcolor
-from tkinter import filedialog
 import matplotlib.pyplot as plt
 import numpy as np
 import platform
 import tkinter as tk
 from tkinter import messagebox
-import importlib.resources
-
 
 PLATFORM = platform.system()
 
@@ -27,37 +24,30 @@ try:
     from .plot_functions import plot_class
 except ImportError:
     from plot_functions import plot_class
+try:
+    if PLATFORM == "Linux":
+        from .tkGUI_linux import create_GUI
+        plt.rcParams["font.family"] = 'DeJaVu Serif'
+    elif PLATFORM == "Darwin":
+        from .tkGUI_Mac import create_GUI
+        plt.rcParams["font.family"] = 'DeJaVu Serif'
+    else:
+        from .tkGUI import create_GUI
+        plt.rcParams["font.family"] = "Times New Roman"
+except ImportError:
+    if PLATFORM == "Linux":
+        from tkGUI_linux import create_GUI
+        plt.rcParams["font.family"] = 'DeJaVu Serif'
+    elif PLATFORM == "Darwin":
+        from tkGUI_Mac import create_GUI
+        plt.rcParams["font.family"] = 'DeJaVu Serif'
+    else:
+        from tkGUI import create_GUI
+        plt.rcParams["font.family"] = "Times New Roman"
 
-
-if PLATFORM == "Linux":
-    plt.rcParams["font.family"] = 'DeJaVu Serif'
-    with importlib.resources.path(__package__, "pltEditorGUI-1.ui") as ui_path:
-        form_class = uic.loadUiType(ui_path)[0]
-elif PLATFORM == "Darwin":
-    plt.rcParams["font.family"] = 'DeJaVu Serif'
-    with importlib.resources.path(__package__, "pltEditorGUI-1.ui") as ui_path:
-        form_class = uic.loadUiType(ui_path)[0]
-else:
-    plt.rcParams["font.family"] = "Times New Roman"
-    with importlib.resources.path(__package__, "pltEditorGUI-1.ui") as ui_path:
-        form_class = uic.loadUiType(ui_path)[0]
 plt.rcParams['mathtext.fontset'] = 'stix'
 
-# if PLATFORM == "Linux":
-#     plt.rcParams["font.family"] = 'DeJaVu Serif'
-#     ui_path = "pltEditorGUI-1.ui"
-#     form_class = uic.loadUiType(ui_path)[0]
-# elif PLATFORM == "Darwin":
-#     plt.rcParams["font.family"] = 'DeJaVu Serif'
-#     ui_path = "pltEditorGUI-1.ui"
-#     form_class = uic.loadUiType(ui_path)[0]
-# else:
-#     plt.rcParams["font.family"] = "Times New Roman"
-#     ui_path = "pltEditorGUI-1.ui"
-#     form_class = uic.loadUiType(ui_path)[0]
-# plt.rcParams['mathtext.fontset'] = 'stix'
-
-
+form_class = uic.loadUiType("pltEditorGUI-1.ui")[0]
 
 class MyWindowClass(QtWidgets.QMainWindow, form_class):
     def __init__(self, parent, data_dict):
@@ -95,12 +85,6 @@ class MyWindowClass(QtWidgets.QMainWindow, form_class):
         self.btnRemPlot.clicked.connect(self.rem_plot)
         self.btnGenPlot.clicked.connect(self.show_plot)
         self.btnSavePlot.clicked.connect(self.save_plot)
-        self.chbColorMatch1.stateChanged.connect(self.match1_change)
-        self.chbColorMatch2.stateChanged.connect(self.match2_change)
-        self.chbColorMatch3.stateChanged.connect(self.match3_change)
-        self.chbColorMatch4.stateChanged.connect(self.match4_change)
-        self.chbColorMatch5.stateChanged.connect(self.match5_change)
-        self.chbColorMatch6.stateChanged.connect(self.match6_change)
         
     def populate_GUI(self):
         self.tabWidget.setCurrentIndex(0)
@@ -113,66 +97,48 @@ class MyWindowClass(QtWidgets.QMainWindow, form_class):
         sSheet = 'background-color: rgb({}, {}, {});'.format(new_col[0]*255, 
                                                              new_col[1]*255, 
                                                              new_col[2]*255)
-        if self.chbColorMatch1.isChecked():
-            self.changeAllColors(new_col, sSheet)
-        else:
-            self.btnEBCol.setStyleSheet(sSheet)
-            self.colors['Errorbar'] = new_col
+        self.btnEBCol.setStyleSheet(sSheet)
+        self.colors['Errorbar'] = new_col
     
     def lColChange(self):
         new_col = get_color(self.colors['Line'])
         sSheet = 'background-color: rgb({}, {}, {});'.format(new_col[0]*255, 
                                                              new_col[1]*255, 
                                                              new_col[2]*255)
-        if self.chbColorMatch1.isChecked():
-            self.changeAllColors(new_col, sSheet)
-        else:
-            self.btnLCol.setStyleSheet(sSheet)
-            self.colors['Line'] = new_col
+        self.btnLCol.setStyleSheet(sSheet)
+        self.colors['Line'] = new_col
         
     def meColChange(self):
         new_col = get_color(self.colors['MarkerEdge'])
         sSheet = 'background-color: rgb({}, {}, {});'.format(new_col[0]*255, 
                                                              new_col[1]*255, 
                                                              new_col[2]*255)
-        if self.chbColorMatch1.isChecked():
-            self.changeAllColors(new_col, sSheet)
-        else:
-            self.btnMEC.setStyleSheet(sSheet)
-            self.colors['MarkerEdge'] = new_col
+        self.btnMEC.setStyleSheet(sSheet)
+        self.colors['MarkerEdge'] = new_col
         
     def mfColChange(self):
         new_col = get_color(self.colors['MarkerFace'])
         sSheet = 'background-color: rgb({}, {}, {});'.format(new_col[0]*255, 
                                                              new_col[1]*255, 
                                                              new_col[2]*255)
-        if self.chbColorMatch1.isChecked():
-            self.changeAllColors(new_col, sSheet)
-        else:
-            self.btnMFC.setStyleSheet(sSheet)
-            self.colors['MarkerFace'] = new_col
+        self.btnMFC.setStyleSheet(sSheet)
+        self.colors['MarkerFace'] = new_col
         
     def ffColChange(self):
         new_col = get_color(self.colors['FillFace'])
         sSheet = 'background-color: rgb({}, {}, {});'.format(new_col[0]*255, 
                                                              new_col[1]*255, 
                                                              new_col[2]*255)
-        if self.chbColorMatch1.isChecked():
-            self.changeAllColors(new_col, sSheet)
-        else:
-            self.btnFFC.setStyleSheet(sSheet)
-            self.colors['FillFace'] = new_col
+        self.btnFFC.setStyleSheet(sSheet)
+        self.colors['FillFace'] = new_col
         
     def feColChange(self):
         new_col = get_color(self.colors['FillEdge'])
         sSheet = 'background-color: rgb({}, {}, {});'.format(new_col[0]*255, 
                                                              new_col[1]*255, 
                                                              new_col[2]*255)
-        if self.chbColorMatch1.isChecked():
-            self.changeAllColors(new_col, sSheet)
-        else:
-            self.btnFEC.setStyleSheet(sSheet)
-            self.colors['FillEdge'] = new_col
+        self.btnFEC.setStyleSheet(sSheet)
+        self.colors['FillEdge'] = new_col
         
     def seColChange(self):
         new_col = get_color(self.colors['ScatterEdge'])
@@ -190,22 +156,6 @@ class MyWindowClass(QtWidgets.QMainWindow, form_class):
         self.btnScatFCol.setStyleSheet(sSheet)
         self.colors['ScatterFace'] = new_col
         
-    def changeAllColors(self, new_col, sSheet):
-        self.btnFEC.setStyleSheet(sSheet)
-        self.colors['FillEdge'] = new_col
-        self.btnFFC.setStyleSheet(sSheet)
-        self.colors['FillFace'] = new_col
-        self.btnMFC.setStyleSheet(sSheet)
-        self.colors['MarkerFace'] = new_col
-        self.btnMEC.setStyleSheet(sSheet)
-        self.colors['MarkerEdge'] = new_col
-        self.btnLCol.setStyleSheet(sSheet)
-        self.colors['Line'] = new_col
-        self.btnEBCol.setStyleSheet(sSheet)
-        self.colors['Errorbar'] = new_col
-        
-        
-        
     def select_multi(self):
         if self.chbSelMult.isChecked():
             self.lstPlotSel.addItem(self.current_plot)
@@ -321,146 +271,21 @@ class MyWindowClass(QtWidgets.QMainWindow, form_class):
 
         if (self.chbShareX.isChecked() == 0) and (self.chbShareY.isChecked() == 0):
             plot_obj.show_plot(False)
+            # print(plot_dict)
         else:
-            plot_obj.show_plot_sharexy(False)
+            # plot_obj.show_plot_sharexy(False)
+            pass
         
     def save_plot(self):
-        plt.close(1)
-        self.collect_current_data()
-
-        file = QtWidgets.QFileDialog.getSaveFileName(self, 'Save Matplotlib Figure', 'figure1', "Images (*.png)")
-        #filedialog.asksaveasfile(defaultextension='.png',
-                                        #title='Save Matplotlib Figure',
-                                        #filetypes=[('png files (*.png)',
-                                                    #'*.png')])
-        if file[0] == '':
-            return                                            
-        test_grid = np.zeros((self.sbRowNum.value(), self.sbColNum.value()))
-
-        plot_dict = {}
-        plot_dict['axes'] = list(self.axis_dict.keys())
-        plot_dict['axis data'] = self.axis_dict
-        plot_dict['fig_size'] = [2+2*self.sbRowNum.value(), 2.5+2.5*self.sbColNum.value()]
-        plot_dict['gsr'] = self.sbRowNum.value()
-        plot_dict['gsc'] = self.sbColNum.value()
-        plot_dict['sharex'] = self.chbShareX.isChecked()
-        plot_dict['sharey'] = self.chbShareY.isChecked()
-        plot_dict['Fig_title'] = {'title':self.eFigTitle.text(),
-                                  'size':self.sbFigTitSz.value(),
-                                  'bold':self.chbFigTitBold.isChecked(),
-                                  'italic':self.chbFigTitIt.isChecked()}
-        plot_dict['Fig_legend'] = {'position':self.cbFigLegPos.currentText(),
-                                   'size':self.sbFigLegFontSz.value(),
-                                   'ncol':self.sbFigLegNcol.value(),
-                                   'correction':self.sbFigPlotCor.value()}
-        
-        plot_obj = plot_class(plot_dict, file[0])
-
-        try:
-            for axis in plot_dict['axes']:
-                data = plot_dict['axis data'][axis]
-                for i in range(data['position'][2]):
-                    for j in range(data['position'][3]):
-                        test_grid[data['position'][0]+i, data['position'][1]+j] = 1
-            if np.sum(test_grid) != plot_dict['gsr']*plot_dict['gsc']:
-                QtWidgets.QMessageBox.warning(self, 'Grid Error', "All Grid Spaces must be filled!")
-                return
-        except IndexError:
-            QtWidgets.QMessageBox.warning(self, 'Grid Error', "Grid index of plot exceeds Grid Bounds!")
-            return
-
-        if (self.chbShareX.isChecked() == 0) and (self.chbShareY.isChecked() == 0):
-            plot_obj.show_plot(True)
-        else:
-            plot_obj.show_plot_sharexy(True)
+        x = [1,2,3,4,5]
+        y = [2,3,4,5,6]
+        plt.plot(x,y)
+        plt.show()
         
     def collect_current_data(self):
         save_plot_data(self, self.current_plot)
         save_axis_data(self, self.selected_axis_value)
-        
-    def match1_change(self):
-        if self.chbColorMatch1.isChecked():
-            self.chbColorMatch2.setChecked(True)
-            self.chbColorMatch3.setChecked(True)
-            self.chbColorMatch4.setChecked(True)
-            self.chbColorMatch5.setChecked(True)
-            self.chbColorMatch6.setChecked(True)
-        else:
-            self.chbColorMatch2.setChecked(False)
-            self.chbColorMatch3.setChecked(False)
-            self.chbColorMatch4.setChecked(False)
-            self.chbColorMatch5.setChecked(False)
-            self.chbColorMatch6.setChecked(False)
-            
-    def match2_change(self):
-        if self.chbColorMatch2.isChecked():
-            self.chbColorMatch1.setChecked(True)
-            self.chbColorMatch3.setChecked(True)
-            self.chbColorMatch4.setChecked(True)
-            self.chbColorMatch5.setChecked(True)
-            self.chbColorMatch6.setChecked(True)
-        else:
-            self.chbColorMatch1.setChecked(False)
-            self.chbColorMatch3.setChecked(False)
-            self.chbColorMatch4.setChecked(False)
-            self.chbColorMatch5.setChecked(False)
-            self.chbColorMatch6.setChecked(False)
-            
-    def match3_change(self):
-        if self.chbColorMatch3.isChecked():
-            self.chbColorMatch2.setChecked(True)
-            self.chbColorMatch1.setChecked(True)
-            self.chbColorMatch4.setChecked(True)
-            self.chbColorMatch5.setChecked(True)
-            self.chbColorMatch6.setChecked(True)
-        else:
-            self.chbColorMatch2.setChecked(False)
-            self.chbColorMatch1.setChecked(False)
-            self.chbColorMatch4.setChecked(False)
-            self.chbColorMatch5.setChecked(False)
-            self.chbColorMatch6.setChecked(False)
-            
-    def match4_change(self):
-        if self.chbColorMatch4.isChecked():
-            self.chbColorMatch2.setChecked(True)
-            self.chbColorMatch3.setChecked(True)
-            self.chbColorMatch1.setChecked(True)
-            self.chbColorMatch5.setChecked(True)
-            self.chbColorMatch6.setChecked(True)
-        else:
-            self.chbColorMatch2.setChecked(False)
-            self.chbColorMatch3.setChecked(False)
-            self.chbColorMatch1.setChecked(False)
-            self.chbColorMatch5.setChecked(False)
-            self.chbColorMatch6.setChecked(False)
-            
-    def match5_change(self):
-        if self.chbColorMatch5.isChecked():
-            self.chbColorMatch2.setChecked(True)
-            self.chbColorMatch3.setChecked(True)
-            self.chbColorMatch4.setChecked(True)
-            self.chbColorMatch1.setChecked(True)
-            self.chbColorMatch6.setChecked(True)
-        else:
-            self.chbColorMatch2.setChecked(False)
-            self.chbColorMatch3.setChecked(False)
-            self.chbColorMatch4.setChecked(False)
-            self.chbColorMatch1.setChecked(False)
-            self.chbColorMatch6.setChecked(False)
-    
-    def match6_change(self):
-        if self.chbColorMatch5.isChecked():
-            self.chbColorMatch2.setChecked(True)
-            self.chbColorMatch3.setChecked(True)
-            self.chbColorMatch4.setChecked(True)
-            self.chbColorMatch5.setChecked(True)
-            self.chbColorMatch1.setChecked(True)
-        else:
-            self.chbColorMatch2.setChecked(False)
-            self.chbColorMatch3.setChecked(False)
-            self.chbColorMatch4.setChecked(False)
-            self.chbColorMatch5.setChecked(False)
-            self.chbColorMatch1.setChecked(False)
+
 
 
 def get_color(color):
@@ -505,11 +330,11 @@ def set_plot_data(window, index):
     styleSheet = 'background-color: rgb({}, {}, {});'.format(window.colors['ScatterFace'][0]*255,
                                                              window.colors['ScatterFace'][1]*255,
                                                              window.colors['ScatterFace'][2]*255)
-    window.btnScatFCol.setStyleSheet(styleSheet)
+    window.btnScatECol.setStyleSheet(styleSheet)
     styleSheet = 'background-color: rgb({}, {}, {});'.format(window.colors['ScatterEdge'][0]*255,
                                                              window.colors['ScatterEdge'][1]*255,
                                                              window.colors['ScatterEdge'][2]*255)
-    window.btnScatECol.setStyleSheet(styleSheet)
+    window.btnScatFCol.setStyleSheet(styleSheet)
     
     window.chbEB.setChecked(currentData['ebar']['exist'])
     window.sbEBLW.setValue(currentData['ebar']['linew'])
@@ -532,7 +357,7 @@ def set_plot_data(window, index):
     window.sbFEW.setValue(currentData['fill']['line_wid'])
     window.cbFES.setCurrentText(currentData['fill']['line_sty'])
     
-    window.chbS.setChecked(currentData['scatter']['exist'])
+    window.chbS.setChecked(0)
     window.cbSMT.setCurrentText(currentData['scatter']['type'])
     window.cbSCV.addItems(currentData['scatter']['color_vector_names']) 
     window.cbSCV.setCurrentText(currentData['scatter']['current_color'])
@@ -556,8 +381,9 @@ def save_plot_data(window, index, multi=False):
     currentData['fill']['face_col'] = window.colors['FillFace']
     currentData['fill']['edge_col'] = window.colors['FillEdge']
     currentData['scatter']['face_col'] = window.colors['ScatterFace']
-    currentData['scatter']['edge_col'] = window.colors['ScatterEdge']
+    currentData['scatter']['edge'] = window.colors['ScatterEdge']
 
+    
     currentData['ebar']['exist'] = window.chbEB.isChecked()
     currentData['ebar']['linew'] = window.sbEBLW.value()
     currentData['ebar']['capsize'] = window.sbEBCS.value()
@@ -760,14 +586,14 @@ def add_plot_to_axis(window):
         window.axis_dict[window.selected_axis_value]['plots'].append(plot_name)
         window.axis_dict[window.selected_axis_value]['plots_data'].append(window.data_dict[plot_name])
 
-        if np.max(window.data_dict[plot_name]['x'][np.where(np.isfinite(window.data_dict[plot_name]['x']))]) > max_x:
-            max_x = np.max(window.data_dict[plot_name]['x'][np.where(np.isfinite(window.data_dict[plot_name]['x']))])
-        if np.max(window.data_dict[plot_name]['y'][np.where(np.isfinite(window.data_dict[plot_name]['y']))]) > max_y:
-            max_y = np.max(window.data_dict[plot_name]['y'][np.where(np.isfinite(window.data_dict[plot_name]['y']))])
-        if np.min(window.data_dict[plot_name]['x'][np.where(np.isfinite(window.data_dict[plot_name]['x']))]) < min_x:
-            min_x = np.min(window.data_dict[plot_name]['x'][np.where(np.isfinite(window.data_dict[plot_name]['x']))])
-        if np.min(window.data_dict[plot_name]['y'][np.where(np.isfinite(window.data_dict[plot_name]['y']))]) < min_y:
-            min_y = np.min(window.data_dict[plot_name]['y'][np.where(np.isfinite(window.data_dict[plot_name]['y']))])
+        if np.max(window.data_dict[plot_name]['x']) > max_x:
+            max_x = np.max(window.data_dict[plot_name]['x'])
+        if np.max(window.data_dict[plot_name]['y']) > max_y:
+            max_y = np.max(window.data_dict[plot_name]['y'])
+        if np.min(window.data_dict[plot_name]['x']) < min_x:
+            min_x = np.min(window.data_dict[plot_name]['x'])
+        if np.min(window.data_dict[plot_name]['y']) < min_y:
+            min_y = np.min(window.data_dict[plot_name]['y'])
         window.axis_dict[window.selected_axis_value]['x_lim'] = [min_x, max_x]
         window.axis_dict[window.selected_axis_value]['y_lim'] = [min_y, max_y]
 
@@ -786,24 +612,24 @@ def remove_plot_from_axis(window):
     temp_plots = []
     temp_plots_data = []
     window.cbSelData.clear()
-    max_x = window.axis_dict[window.selected_axis_value]['x_lim'][1]
-    min_x = window.axis_dict[window.selected_axis_value]['x_lim'][0]
-    max_y = window.axis_dict[window.selected_axis_value]['y_lim'][1]
-    min_y = window.axis_dict[window.selected_axis_value]['x_lim'][0]
+    max_x = -1e16
+    min_x = 1e16
+    max_y = -1e16
+    min_y = 1e16
 
     for i in range(len(window.axis_dict[window.selected_axis_value]['plots'])):
         if window.axis_dict[window.selected_axis_value]['plots'][i] != plot_name:
             plot_name_temp = window.axis_dict[window.selected_axis_value]['plots'][i]
             temp_plots.append(window.axis_dict[window.selected_axis_value]['plots'][i])
             temp_plots_data.append(window.data_dict[window.axis_dict[window.selected_axis_value]['plots'][i]])
-            if np.max(window.data_dict[plot_name_temp]['x'][np.where(np.isfinite(window.data_dict[plot_name_temp]['x']))]) > max_x:
-                max_x = np.max(window.data_dict[plot_name_temp]['x'][np.where(np.isfinite(window.data_dict[plot_name_temp]['x']))])
-            if np.max(window.data_dict[plot_name_temp]['y'][np.where(np.isfinite(window.data_dict[plot_name_temp]['y']))]) > max_y:
-                max_y = np.max(window.data_dict[plot_name_temp]['y'][np.where(np.isfinite(window.data_dict[plot_name_temp]['y']))])
-            if np.min(window.data_dict[plot_name_temp]['x'][np.where(np.isfinite(window.data_dict[plot_name_temp]['x']))]) < min_x:
-                min_x = np.min(window.data_dict[plot_name_temp]['x'][np.where(np.isfinite(window.data_dict[plot_name_temp]['x']))])
-            if np.min(window.data_dict[plot_name_temp]['y'][np.where(np.isfinite(window.data_dict[plot_name_temp]['y']))]) < min_y:
-                min_y = np.min(window.data_dict[plot_name_temp]['y'][np.where(np.isfinite(window.data_dict[plot_name_temp]['y']))])
+            if np.max(window.data_dict[plot_name_temp]['x']) > max_x:
+                max_x = np.max(window.data_dict[plot_name_temp]['x'])
+            if np.max(window.data_dict[plot_name_temp]['y']) > max_y:
+                max_y = np.max(window.data_dict[plot_name_temp]['y'])
+            if np.min(window.data_dict[plot_name_temp]['x']) < min_x:
+                min_x = np.min(window.data_dict[plot_name_temp]['x'])
+            if np.min(window.data_dict[plot_name_temp]['y']) < min_y:
+                min_y = np.min(window.data_dict[plot_name_temp]['y'])
 
     if temp_plots == []:
         window.axis_dict[window.selected_axis_value]['plots'] = ['']
